@@ -44,7 +44,7 @@ enum ConversionStatus {
  * HISTORY: this was a base class for Catalog import plugins in KBabel,
  * but this architecture isn't not suitable for XML-based files
  * (when whole DOM-tree is stored in memory to prevent file clashes)
-  *
+ *
  * This class is the base for import plugins for catalogs.
  * It provides "transactional behavior", so the changes are stored in
  * catalog only if the import process finishes successfully.
@@ -56,7 +56,7 @@ enum ConversionStatus {
  * @short Base class for GettextCatalog import plugins
  * @author Stanislav Visnovsky <visnovsky@kde.org>
  */
-class  CatalogImportPlugin
+class CatalogImportPlugin
 {
 public:
     CatalogImportPlugin();
@@ -72,36 +72,36 @@ public:
      * @param errorLine the number of erroneous line
      * @return result of the operation
      */
-    ConversionStatus open(QIODevice*, GettextStorage* catalog, int* errorLine);
+    ConversionStatus open(QIODevice *, GettextStorage *catalog, int *errorLine);
 
     /**
-    * Reimplement this method to load the local file passed as an argument.
-    * Throughout the run, you can use the protected methods for setting
-    * the contents of the resulting catalog.
-    * This method must call \see setMimeTypes to setup correct MIME types
-    * for the loaded file. Also, it should use \see isStopped to
-    * abort loading and the signals for providing user feedback.
-    * @param device file to be loaded
-    */
-    virtual ConversionStatus load(QIODevice*) = 0;
+     * Reimplement this method to load the local file passed as an argument.
+     * Throughout the run, you can use the protected methods for setting
+     * the contents of the resulting catalog.
+     * This method must call \see setMimeTypes to setup correct MIME types
+     * for the loaded file. Also, it should use \see isStopped to
+     * abort loading and the signals for providing user feedback.
+     * @param device file to be loaded
+     */
+    virtual ConversionStatus load(QIODevice *) = 0;
 
 protected:
     /** Append a new catalog item, either as normal or as an obsolete one
      *  @param item the new item
      *  @param obsolete flag that the item is obsolete
      */
-    void appendCatalogItem(const CatalogItem& item, const bool obsolete = false);
+    void appendCatalogItem(const CatalogItem &item, const bool obsolete = false);
 
     /** set flag that the file is generated from DocBook */
     void setGeneratedFromDocbook(const bool fromDocbook);
     /** set the list of parse error indexes */
-    void setErrorIndex(const QList<int>& errors);
+    void setErrorIndex(const QList<int> &errors);
 
     /** set extra data for the catalog, which can't be stored in
      *  @ref CatalogItem. The format can be arbitrary */
-    void setCatalogExtraData(const QStringList& data);
+    void setCatalogExtraData(const QStringList &data);
     /** set the header catalog item */
-    void setHeader(const CatalogItem& header);
+    void setHeader(const CatalogItem &header);
 
     /** Set the character encoding used in the catalog file. */
     void setCodec(const QByteArray &codec);
@@ -112,11 +112,10 @@ protected:
     void commitTransaction();
 
     short _maxLineLength{0};
-    short _trailingNewLines{0};
     int _errorLine{0};
 
 private:
-    CatalogImportPluginPrivate* d;
+    CatalogImportPluginPrivate *d;
 };
 
 }
