@@ -54,7 +54,6 @@ public:
     void showEvent(QShowEvent *event) override;
 
 Q_SIGNALS:
-    //     void textReplaceRequested(const QString&);
     void refreshRequested();
     void textInsertRequested(const QString &);
     void fileOpenRequested(const QString &filePath, const QString &str, const QString &ctxt, const bool setAsActive);
@@ -90,7 +89,7 @@ private:
     void runJobs();
 
 private:
-    DynamicItemHeightQListWidget *m_tm_entries_list{nullptr};
+    DynamicItemHeightQListWidget *m_entriesList{nullptr};
     Catalog *m_catalog{nullptr};
     DocPosition m_pos;
 
